package org.ferris.net;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;

import org.apache.commons.codec.binary.Base64;
import org.apache.log4j.Logger;

/**
 * Opens a URLConnection and uses the given credentials
 * to pass a username and password along for doing
 * HTTP basic authentication.  
 * 
 * @author <a href="mailto:mjremijan@yahoo.com">Mike Remijan</a>
 *
 */
public class BasicAuthenticationUrlConnection
{
	private Logger log = Logger.getLogger(getClass());
	
	private void setUrl(URL url) {
		log.info("URL=" + url.toString());
		this.url = url;
	}
	private URL getUrl() {
		return url;
	}	
	private void setCredentials(String username, String clearTextPassword) {
		this.credentials = username + ":" + clearTextPassword;
		this.credentials = new String(new Base64().encode(this.credentials.getBytes()));
	}
	private String getCredentials() {
		return credentials;
	}
	private void setConnection() throws IOException {
		connection = getUrl().openConnection();
	    connection.setRequestProperty("Authorization", "Basic " + getCredentials());	
	}
	private void setInputStream() throws IOException {
		is = getUrlConnection().getInputStream();
	}
		
	private URL url;
	private String credentials;
	private URLConnection connection;
	private InputStream is;
	
	/**
	 * Establishes a connection which can be read from
	 * the <code>InputStream</code> from this object.
	 * The username and password are Base64 encoded before 
	 * sending them out so don't worry about a clear text 
	 * password being sent over the network. Make sure
	 * you call <code>close()</code> when you're done.
	 * 
	 * @param url - The URL.
	 * 
	 * @param username - The basic authentication username
	 * 
	 * @param clearTextPassword - The basic authentication 
	 * clear text password.  This (along with the username)
	 * will be Base64 encoded before sending it out so don't
	 * worry about a clear text password being sent over 
	 * the network. 
	 * 
	 * @throws IOException
	 * Thrown if opening the connection to the URL fails.
	 */
	public BasicAuthenticationUrlConnection(
		  URL url
		, String username
		, String clearTextPassword
	)
	throws IOException
	{
		setUrl(url);
		setCredentials(username, clearTextPassword);
		setConnection();
		setInputStream();
	}
	
	
	/**
	 * Get the <code>URLConnection</code> object 
	 * created by this class's constructor.
	 */
	public URLConnection getUrlConnection() {
		return connection;
	}
	
	
	/**
	 * Get the <code>InputStream</code> 
	 * from the <code>URLConnection</code>.
	 * Make sure you remember to call 
	 * <code>close()</code>!!
	 * 
	 * @see #getUrlConnection()
	 * @see #close()
	 */
	public InputStream getInputStream() {
		return is;
	}
	
	
	/**
	 * Sets all properties to null and closes the
	 * <code>InputStream</code>
	 */
	public void close() {
		url = null;
		credentials = null;		
		connection = null;
		try {is.close();} catch (Throwable ignore) {} finally { is=null;}
	}
	
	
	
	
}
