package org.ferris.net;


/**
 * Most exceptions, runtime or checked, are fatal and the purpose
 * of this class is to wrap all checked exceptions and rethrow them
 * as a runtime exception.  The purpose of doing this is to prevent
 * littering the code with useless try/catch blocks.  
 * Chances are if an exception is raised the application will not
 * be able to recover. 
 * 
 * @author <a href="mailto:mjremijan@yahoo.com">Mike Remijan</a>
 *
 */
public class NetException extends RuntimeException 
{
	private static final long serialVersionUID = 79347556969894985L;

	private NetExceptionCode code;
	
	public NetException(NetExceptionCode code, Object...messageParams)
	{
		super(code.getMessage(messageParams));
		this.code = code;
	}
	
	public NetException(NetExceptionCode code, Throwable throwable, Object...messageParams)
	{
		super(code.getMessage(messageParams), throwable);
		this.code = code;
	}
	
	public NetExceptionCode getCode() {
		return code;
	}
}
