package org.ferris.net.runner;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;

/**
 * The purpose of this class is to take a relative URL
 * like this "/some/kind/of/path/to/resource.jsp?fname=?&lname=?" 
 * and break it into a resource and a list of parameter names
 * where resource = "/some/kind/of/path/to/resource.jsp"
 * and parameter names = ["fname","lname"].  The resource
 * and list of parameter names will be used by the HttpRequestRunner
 * to make the request to the correct resource and to 
 * appropriately set the request parameters. 
 * 
 * @author <a href="mailto:mjremijan@yahoo.com">Mike Remijan</a>
 *
 */
public class HttpRequestParser 
{
	private Logger log = Logger.getLogger(getClass());
	
	/**
	 * Extract 
	 * "/some/kind/of/path/to/resource.jsp" 
	 * from 
	 * "/some/kind/of/path/to/resource.jsp?fname=?&lname=?"
	 */
	private void setResource(String request)
	{
		String [] split = request.split("\\?");
		this.resource = split[0];
		log.info("Resource=\""+this.resource+"\"");
	}
	
	/**
	 * Extract 
	 * ["fname","lname"] 
	 * from 
	 * "/some/kind/of/path/to/resource.jsp?fname=?&lname=?"
	 */
	private void setParameters(String request)
	{
		parameters = new ArrayList<String>();
		
		request = request.replace("&", "");
		request = request.replace("=", "");
		
		// "/some/kind/of/path/to/resource.jsp?fname?lname?"
		String [] split = request.split("\\?");
		for (int i=1; i<split.length; i++) {
			log.info("Add parameter name=\""+split[i]+"\"");
			parameters.add(split[i]);
		}
	}
	
	private String resource;
	private List<String> parameters;
	
	/**
	 * Splits the request in a String representing
	 * the resource and a List<String> representing
	 * the names of the request parameters. So,
	 * given "/some/kind/of/path/to/resource.jsp?fname=?&lname=?"
	 * resource="/some/kind/of/path/to/resource.jsp" and
	 * list=["fname","lname"]
	 * @param request
	 */
	public HttpRequestParser(String request) {
		setResource(request);
		setParameters(request);
	}
	
	/**
	 * Return "/some/kind/of/path/to/resource.jsp" of 
	 * "/some/kind/of/path/to/resource.jsp?fname=?&lname=?"
	 */
	public String getResource() {
		return resource;
	}
	
	/**
	 * Return ["fname","lname"] of 
	 * "/some/kind/of/path/to/resource.jsp?fname=?&lname=?"
	 */
	public List<String> getParameters() {
		return parameters;
	}
}
