package org.ferris.net.runner;

import java.io.InputStream;
import java.util.List;

/**
 * This interface defines a way for the results from
 * the web server to be processed.  Implementations of
 * this interface should process the <code>InputStream</code>
 * from the web server and turn it into a <code>List</code>
 * of some kind of object.
 * 
 * @author <a href="mailto:mjremijan@yahoo.com">Mike Remijan</a>
 *
 * @param <M>
 */
public interface HttpResponseHandler<M> {
	
	/**
	 * A response from an HTTP server can be anything so
	 * an InputStream allows the handler the most flexibility
	 * to respond accordingly.  For example, the response
	 * can be a tab delimited data file, an XML document,
	 * or a PDF.  
	 * @param response
	 * @return
	 */
	public List<M> response(InputStream response);
	
}
