package org.ferris.net.runner;

import org.apache.http.auth.AuthScope;
import org.apache.http.auth.UsernamePasswordCredentials;

/**
 * The same as <code>HttpRequestRunner</code> only HTTPS is used.
 * 
 * @author <a href="mailto:mjremijan@yahoo.com">Mike Remijan</a>
 *
 * @param <M>
 */
public class HttpsRequestRunner<M> extends HttpRequestRunner<M>
{
	/**
	 * This constructor is used if the HTTP 
	 * resource is <b>NOT</b> protected by 
	 * BASIC authentication.
	 * 
	 * @param authScope
	 */
	public HttpsRequestRunner(AuthScope authScope) {
		super(authScope, null);
	}
	
	
	/**
	 * This constructor is used if the HTTP 
	 * resource <b>IS</b> protected by 
	 * BASIC authentication.
	 * 
	 * @param authScope
	 */
	public HttpsRequestRunner(AuthScope authScope, UsernamePasswordCredentials credentials) {
		super(authScope, credentials);
	}

	/**
	 * The "https" of the URL "https://localhost:8080/some/path/search.php",
	 * must begin with a "/" and not end with a "/".  Override this method
	 * in sub-classes if https is needed instead.
	 */
    @Override
	protected String getScheme() {
		return "https";
	}
	
}
